# History

## 0.4.0 (2020-12-26)

* **(Breaking)** Drop all texture-related features, except very basic
  ones

## 0.3.0 (2020-12-26)

* Various bugfixes

## 0.2.0 (2020-12-26)

* **(Breaking)** Drop password field from User model

## 0.1.0 (2020-12-26)

* First release on PyPI.
